#ifndef E_test_config_h
#define E_test_config_h

#define TEST_SRC_DIR "/usr/local/tmp/libdap-3.9.3/unit-tests"

#endif

